#! /bin/sh
#
#  bootstrap_rpm.sh   install full featured rpm with busybox-rpm
#

# set -x

i_log=/root/scripts/install.log

/root/scripts/mount_installsource.sh

# Bootstrap rpm of Fedora with busybox rpm and busybox rpm2cpio
RPM_PATH="/mnt/cdrom/${distri}/RPMS/"
RPM_COMMAND="/bin/busybox rpm -i ${RPM_PATH}"

# Install rpm of Fedora
# This list was created by recursively following the dependencies of rpm
# in FC2: rpm -qR -p rpm-4.3.1-0.3.i386.rpm  and for all of its dependencies
# in FC3: rpm -qR -p rpm-4.3.2-2.i386.rpm  and for all of its dependencies

# echo bootstrap rpm: method=$method version=$version
# read x

dialog --no-cancel --no-collapse --msgbox \
"    Fedora Core ${version} is going to be installed by it's own rpm.
    This is performed with a 3-step process:
    1) install FC cpio with busybox rpm
    2) install FC rpm with busybox rpm2cpio using cpio from 1)
    3) install FC with rpm from 2)

    While doing 1) You will see some messages like:
    *) ... File exists
    *) need to fix this

    Ignore them :-)
" 17 70

case $method in
'cdrom'|'iso'|'rpms'|'nfsiso'|'nfsrpms')
    case $version in
    '5')
	# echo
	# echo Bootstrap full featured rpm with busybox-rpm from $method
	# echo hit ENTER; read x
	filelist=`cat /root/scripts/${version}/rm_links_before_bootstrap_rpm.txt`
	for f in $filelist
	do
	    [ -h $f ] && rm $f
	done

 	rpmlist=`/bin/busybox grep -v '^-- ' /root/scripts/${version}/cpio_packages.disc1`
	for rpm in $rpmlist
	do
 	    echo busybox rpm ${rpm} ====================== | tee -a $i_log
 	    ${RPM_COMMAND}${rpm} 2>&1 | tee -a $i_log
 	done

	dialog --no-cancel --no-collapse --msgbox \
'    Now starting step 2) of the list

    1) install FC cpio with busybox rpm - done
    2) install FC rpm with busybox rpm2cpio using cpio from 1)
    3) install FC with rpm from 2)
' 12 70

        cd /
	rpmlist=`/bin/busybox grep -v '^-- ' /root/scripts/${version}/rpm_packages.disc1`
	for rpm in $rpmlist
	do
	    echo busybox rpm2cpio ${rpm} ====================== | tee -a $i_log
	    /bin/busybox rpm2cpio ${RPM_PATH}/${rpm} | cpio -idu 2>&1 | tee -a $i_log
	done
	cd -
	;;
    esac
	
    # RPM_COMMAND="/bin/rpm -ivh --nodeps --replacepkgs ${RPM_PATH}"
    # RPM_INFO="/bin/rpm -qi -p ${RPM_PATH}"
    # set +x
    ;;

'httprpms')
    mkdir /httptmp
    cd /httptmp

    case $version in
    5)
	filelist=`cat /root/scripts/${version}/rm_links_before_bootstrap_rpm.txt`
	for f in $filelist
	do
	    [ -h $f ] && rm $f
	done

	rpmlist=`/bin/busybox grep -v '^-- ' /root/scripts/${version}/cpio_packages.disc1`
	;;
    esac

    for rpm in $rpmlist
    do
	echo busybox wget -c http://$HOST$FILE_PATH$rpm
	/bin/busybox wget -c http://$HOST$FILE_PATH$rpm || {
	    echo wget failed for http://$HOST$FILE_PATH$rpm | tee -a $i_log
	    echo hit ENTER; read x
	    continue
	}
	echo busybox rpm -i $rpm
	/bin/busybox rpm -i $rpm
	rm $rpm
    done

    dialog --no-cancel --no-collapse --msgbox \
'    Now starting step 2) of the list

    1) install FC cpio with busybox rpm - done
    2) install FC rpm with busybox rpm2cpio using cpio from 1)
    3) install FC with rpm from 2)
' 12 70

    rpmlist=`/bin/busybox grep -v '^-- ' /root/scripts/${version}/rpm_packages.disc1`
    for rpm in $rpmlist
    do
	echo busybox wget -c http://$HOST$FILE_PATH$rpm
	/bin/busybox wget -c http://$HOST$FILE_PATH$rpm || {
	    echo wget failed for http://$HOST$FILE_PATH$rpm | tee -a $i_log
	    echo hit ENTER; read x
	    continue
	}
	echo busybox rpm2cpio ${rpm} ====================== | tee -a $i_log
	cd /
	/bin/busybox rpm2cpio /httptmp/${rpm} | cpio -idu 2>&1 | tee -a $i_log
	cd -
	rm ${rpm}
    done
    cd /
    rm -rf /httptmp
    ;;

'ftprpms')
    # set -x
    mkdir /ftptmp

    # set the ftpget-options
    useropt="-u `echo $LOGIN | cut -d: -f1`"
    passopt="-p `echo $LOGIN | cut -d: -f2`"
    [ "$useropt" = '-u ' ] && useropt=''
    [ "$passopt" = '-p ' ] && passopt=''
    [ -n "$PORT" ] && delim=':' || delim=''
    hostopt="$HOST$delim$PORT"
    pathopt="$FILE_PATH"

    case $version in
    '5')
	filelist=`cat /root/scripts/${version}/rm_links_before_bootstrap_rpm.txt`
	for f in $filelist
	do
	    [ -h $f ] && rm $f
	done

	rpmlist=`/bin/busybox grep -v '^-- ' /root/scripts/${version}/cpio_packages.disc1`
	;;
    esac

    for rpm in $rpmlist
    do
        echo busybox ftpget $rpm | tee -a $i_log
	/bin/busybox ftpget $useropt $passopt $hostopt /ftptmp/$rpm $pathopt/$rpm
	# echo "Return Code was <$?>"
#  || {
# 	    echo ftpget failed for $pathopt/$rpm | tee -a $i_log
# 	    echo hit ENTER; read x
# 	    continue
# 	}
	echo busybox rpm $rpm | tee -a $i_log
	/bin/busybox rpm -i /ftptmp/$rpm
	rm /ftptmp/${rpm}
	sleep 3
    done

    rpmlist=`/bin/busybox grep -v '^-- ' /root/scripts/${version}/rpm_packages.disc1`
    for rpm in $rpmlist
    do
	echo busybox ftpget $rpm | tee -a $i_log
	/bin/busybox ftpget $useropt $passopt $hostopt /ftptmp/$rpm $pathopt/$rpm
	# echo "Return Code was <$?>"
#  || {
# 	    echo ftpget failed for $pathopt/$rpm | tee -a $i_log
# 	    echo hit ENTER; read x
# 	    continue
# 	}
	echo busybox rpm2cpio ${rpm} ====================== | tee -a $i_log
	cd /
	/bin/busybox rpm2cpio /ftptmp/${rpm} | cpio -idu 2>&1 | tee -a $i_log
	cd -
	rm /ftptmp/${rpm}
    done
    cd /
    rm -rf /ftptmp
    # RPM_COMMAND="/bin/rpm -ivh --nodeps --replacepkgs FTP://${LOGIN}${HOST}${PORT}${FILE_PATH}"
    ;;
esac

# if [ "$version" = '4' ]; then
#     # these two links are missing but needed
#     cd lib
#     ln -s libssl.so.0.9.7f libssl.so.5
#     ln -s libcrypto.so.0.9.7f libcrypto.so.5
#     cd -
# fi

	dialog --no-cancel --no-collapse --msgbox \
"    Fedora's rpm should work now.

    Please verify this by typing 'rpm --initdb' from the 2nd
    virtual terminal.

    If this doesn't work correctly something is wrong and
    further installation wont perform.
" 12 70

/root/scripts/unmount_installsource.sh
