#!/bin/sh

# rc.pcmcia 1.39 2001/10/04 12:30:05 (David Hinds)
#
# Modified for the RULE project by Michael Fratoni
# 01/05/2003
# fzk  01.11.2004   trying to get it working with kernel 2.6.9
#                   all files are part of floppy1 now

# First things first, we need to define the path
# To our kernel modules.

module_dir="/lib/modules/`uname -r`/kernel/drivers/pcmcia"
[ ! -d $module_dir ] && {
    echo "Module directory <$module_dir> not found"
    exit 1
}

# if [ -d /mnt/floppy/modules ] ; then
#    module_dir="/mnt/floppy/modules"
# fi

# if [ -d /mnt/cdrom/PCMCIA/modules ] ; then
#    module_dir="/mnt/cdrom/PCMCIA/modules"
# fi

# if [ -z $module_dir ] ; then
#    echo "Unable to determine location of modules."
#    echo "Please edit pcmcia.sh to define"
#    echo "the location of the pcmcia modules."
#    exit
# fi

# processname: cardmgr
# pidfile: /var/run/cardmgr.pid
# config: /etc/pcmcia/config
# config: /etc/pcmcia/config.opts

# Should be either i82365 or tcic
PCIC=i82365
# Put socket driver timing parameters here
PCIC_OPTS=
# Put pcmcia_core options here
CORE_OPTS=
# Put cardmgr options here
CARDMGR_OPTS="-f -m ${module_dir}"
# To set the PCMCIA scheme at startup...
SCHEME=

# in case there are any ENV_{N} variables set put the value into variable {N}
for N in PCMCIA PCIC PCIC_OPTS CORE_OPTS CARDMGR_OPTS SCHEME ; do
    V=`eval echo '$'ENV_$N` ; if [ "$V" ] ; then eval $N=\"$V\" ; fi
done

usage()
{
    echo $"Usage: $0 {start|stop|status|restart|reload}"
}

cleanup()
{
    while read SN CLASS MOD INST DEV EXTRA ; do
	if [ "$SN" != "Socket" ] ; then
	    /etc/pcmcia/$CLASS stop $DEV 2> /dev/null
	fi
    done
}

EXITCODE=1
for x in "1" ; do

    if [ "$PCIC" = "" ] ; then
	echo $"PCIC module not defined in startup options!"
        exit 1
    fi

    if [ $# -lt 1 ] ; then usage ; break ; fi
    action=$1

    case "$action" in

    start)
	echo -n $"Starting PCMCIA services:"
	mkdir -p /var/lib/pcmcia
	mkdir -p /var/run
	mkdir -p /var/lock/subsys
	if [ -d /var/lib/pcmcia ] ; then
	    SC=/var/lib/pcmcia/scheme
	    RUN=/var/lib/pcmcia
	else
	    SC=/var/run/pcmcia-scheme
	    RUN=/var/run
	fi
	if [ -L $SC -o ! -O $SC ] ; then rm -f $SC ; fi
	if [ ! -f $SC ] ; then umask 022 ; touch $SC ; fi
	if [ "$SCHEME" ] ; then umask 022 ; echo $SCHEME > $SC ; fi
	grep -q pcmcia /proc/devices
	if [ $? -ne 0 ] ; then
	    PC=${module_dir}
	fi
	if [ -d $PC ] ; then
	    modprobe pcmcia_core $CORE_OPTS
	    modprobe yenta_socket
	    modprobe tulip
	    modprobe $PCIC $PCIC_OPTS
	    modprobe ds
	else
	    echo $" module directory $PC not found."
	    break
	fi
	if [ -s /var/run/cardmgr.pid ] && \
	    kill -0 `cat /var/run/cardmgr.pid` 2>/dev/null ; then
	    echo $" cardmgr is already running."
	else
	    if [ -r $RUN/stab ] ; then
		cat $RUN/stab | cleanup
	    fi
	    /sbin/cardmgr $CARDMGR_OPTS
	fi
	touch /var/lock/subsys/pcmcia 2>/dev/null

	# Try to bring up the network
	/scripts/init_network.sh
	;;

    stop)
	echo -n $"Shutting down PCMCIA services:"

	ifconfig eth0 down
	sleep 2
	ifconfig eth0 down 
	
	if [ -s /var/run/cardmgr.pid ] ; then
	    PID=`cat /var/run/cardmgr.pid`
	    kill $PID
	    echo -n " cardmgr"
	    # Give cardmgr a few seconds to handle the signal
	    kill -0 $PID 2>/dev/null && sleep 2 && \
	    kill -0 $PID 2>/dev/null && sleep 2 && \
	    kill -0 $PID 2>/dev/null && sleep 2 && \
	    kill -0 $PID 2>/dev/null
	fi

	if grep -q "ds  " /proc/modules ; then
	    /sbin/rmmod ds
	    /sbin/rmmod $PCIC
	    /sbin/rmmod pcmcia_core
	fi
	echo "."
	rm -f /var/lock/subsys/pcmcia

	# we do this because when we stop the service, the ide stop script
	# gets run before the card disappears
	# /usr/sbin/updfstab
	EXITCODE=0
	;;

    status)
	pid=`/sbin/pidof cardmgr`
	if [ "$pid" != "" ] ; then
	    echo $"cardmgr (pid $pid) is running..."
	    EXITCODE=0
	else
	    echo $"cardmgr is stopped"
	    EXITCODE=3
	fi
	;;

    restart|reload)
	$0 stop
	$0 start
	EXITCODE=$?
	;;

    *)
	usage
	;;

    esac

done

exit $EXITCODE  
