#! /bin/sh
#
#  select_method.sh   Select your installation methode

# Let the user select the install method.

[ ! -d /mnt/loop ] && mkdir -p /mnt/loop
[ ! -d /mnt/cdrom ] && mkdir -p /mnt/cdrom

stop_go() {
    echo -n 'Hit ENTER '
    read x
}

ping_ok() {
    echo "Successfully pinged host <$HOST>." | tee -a $i_log
    stop_go
}

ping_notok() {
    echo "Failed to ping host <$HOST>." | tee -a $i_log
    echo 'If this is unexpected, you should quit the install,'
    echo 'and verify that your network is up.'
    stop_go
}

r=/scripts

avail_parts=`/sbin/fdisk -l | grep '^/dev/' | cut -d/ -f3 | cut -d' ' -f1`

cat >$r/method_list.raw <<EOF
cdrom
iso
rpms
httprpms
nfsiso
nfsrpms
ftprpms
EOF

# prefix linenumber
awk '{print ++i " " $1}' $r/method_list.raw >$r/method_list.txt

while :; do
    dialog --no-collapse --title 'Choose installation method' --menu "
    I You get | Source on harddisk | Source on CD I
    I source  |    in format       |              I
    I from:   | Fedora |   rpms**) |   Fedora     I
    I         |  iso*) |           |     iso      I
    I---------------------------------------------I
    I local   |    iso |      rpms |    cdrom     I
    I---------|--------+-----------I--------------I
    I http    |   n/a  |  httprpms I
    I nfs     | nfsiso |   nfsrpms I
    I ftp     |   n/a  |   ftprpms I
    I------------------------------I
    *) ISOs are found, if placed in the top-level-directory of
       a local harddisk-partion or nfs-export-directory.
    **)RPMs are found, if placed in the $distri/RPMS directory.
" 22 70 1 `cat $r/method_list.txt` 2>/tmp/dialog.ipt
    nr=`cat /tmp/dialog.ipt`
    nr=`eval echo $nr`
    method=`grep "^$nr " $r/method_list.txt | cut -d' ' -f2`

    echo "User selected <$method> install type." | tee -a $i_log

    # Make sure we have a valid install type, if not, default to cdrom.

    if [ -z "$method" ]; then
	method='cdrom'
	echo "Defaulting to CDROM install."
    fi
    if [ "$method" != "iso" ] && [ "$method" != "rpms" ] &&\
        [ "$method" != "httprpms"  ] &&\
        [ "$method" != "nfsiso" ]  && [ "$method" != "nfsrpms"  ] &&\
        [ "$method" != "ftprpms"  ] &&\
        [ "$method" != "cdrom" ]; then
        dialog --no-collapse --msgbox \
"    Your input <$method> is not recognized, please try again
" 0 0
        continue
    fi
    break
done
export method

case $method in
'httprpms')
    # HTTPrpm installs. No need for disk swaps here.
    # All of the needed rpms should be in one directory.

    pingok=
    while [ "$pingok" != 'yes' ]; do
	dialog --no-collapse --inputbox \
'    You chose to install rpms via a http server.
    The network connection must be up. If this is not
    the case, switch to the 2nd virtual terminal and
    bring up the network.
    We need to know the server and path to the RPMS.
    
    Please first enter the IP address of the host:
' 16 70 "$inst_server_ip" 2>/tmp/dialog.ipt
	HOST=`cat /tmp/dialog.ipt`

        echo
        echo "Testing connectivity with ping ..."
        ping $HOST
        if [ $? -eq 0 ]; then
	    pingok=yes
	    ping_ok
        else
	    ping_notok
        fi
	dialog --no-collapse --inputbox \
'    Now please enter the full /path/to/the/RPMS/ directory.
    If you placed the RPMS into your public_html directory
    e.g. ~fzk/public_html/Fedora/RPMS on the server $HOST
    then you can accept the default. If you are not fzk
    change this token.

    Enter Path to the RPMS: 
' 16 70 '/~fzk/Fedora/RPMS/' 2>/tmp/dialog.ipt
	FILE_PATH=`cat /tmp/dialog.ipt`
    done
    echo "We will wget http:${HOST}${FILE_PATH}" | tee -a $i_log
    stop_go
    export HOST FILE_PATH
    ;;

'ftprpms')
    # FTPrpm installs. No need for disk swaps here.
    # All of the needed rpms should be in one directory.

    mkdir /ftptmp
    HOST='10.0.0.1'
    PORT=''
    LOGIN='anonymous:slinky@host.dom'
    FILE_PATH='pub/Fedora/RPMS'

    while :
    do
        dialog --no-collapse --form \
"    You chose to install rpms via a ftp server.
    You need to provided the following:

    1) setup networking on this local host
    2) setup ftpd on a server
    3) provide rpms from <$fc5_disc1> for download

    Please enter server, port, login and path to the RPMS.
" 18 70 0 'Server IP/name ' 1 1 "$HOST"      1 17 20 0 \
          'Port (#)       ' 2 1 "$PORT"      2 17 3  0 \
          'Login user:pass' 3 1 "$LOGIN"     3 17 30 0 \
          'Directory      ' 4 1 "$FILE_PATH" 4 17 30 0 2>/tmp/dialog.ipt 
        HOST=`head -1 /tmp/dialog.ipt`
	PORT=`head -2 /tmp/dialog.ipt | tail -1`
        LOGIN=`head -3 /tmp/dialog.ipt | tail -1`
        FILE_PATH=`head -4 /tmp/dialog.ipt | tail -1`

        echo "HOST=<$HOST>" | tee -a $i_log
	echo "PORT=<$PORT>" | tee -a $i_log
        echo "LOGIN=<$LOGIN>" | tee -a $i_log
	echo "FILE_PATH=<$FILE_PATH>" | tee -a $i_log
	# stop_go

        echo "Testing connectivity to <$HOST> with ping ..." | tee -a $i_log
        ping $HOST
        if [ $? -eq 0 ]; then
	    ping_ok
        else
	    ping_notok
        fi

        # set the ftpget-options
	useropt="-u `echo $LOGIN | cut -d: -f1`"
	passopt="-p `echo $LOGIN | cut -d: -f2`"
	[ "$useropt" = '-u ' ] && useropt=''
	[ "$passopt" = '-p ' ] && passopt=''
	[ -n "$port" ] && delim=':' || delim=''
	hostopt="$HOST$delim$PORT"
	pathopt="$FILE_PATH"

	testfile=`grep -v -- '^--' scripts/5/base_packages.disc1 | grep basesystem`
	echo "busybox ftpget ($LOGIN): ${HOST}${delim}${PORT}/${FILE_PATH}/${testfile}" | tee -a $i_log
	/bin/busybox ftpget -v $useropt $passopt $hostopt /ftptmp/$testfile $pathopt/$testfile
	if [ -f /ftptmp/$testfile ]; then
	    echo 'File successfully transfered' | tee -a $i_log
	    stop_go
	    rm /ftptmp/$testfile
	    break
	else
	    echo 'Failed to transfer file, retry' | tee -a $i_log
	    stop_go
	    continue
	fi
    done
    rmdir /ftptmp
    export HOST PORT LOGIN FILE_PATH
    ;;

'nfsrpms')
    # NFSrpms Installs.
    # Currently requires all rpms to be in the same exported directory.
    # Files must be in $distri/RPMS in the exported filesystem.

## nfs is statically compiled into the kernel (cannot load lockd.ko dynamically)
#     /sbin/modprobe nfs > /dev/null 2>&1 || {
#         echo
#         echo "Kernel NFS modules failed to load." | tee -a $i_log
#         echo "Unable to continue, exiting."
#         exit 1
#   echo hit ENTER
#   read x
#     }

    while :
    do
        dialog --no-collapse --inputbox \
"    You choose to install RPMs via a nfs server.
    You need to provided the following:

    1) setup networking on this local host
    2) setup nfs on a server, know the name of the exported dir.
    3) copy all rmps of Fedora Core $version CD-1 into the dir.
       [exported directory]/$distri/RPMS

    Please enter the name of the exported directory,
    In the form of ip:/exported/path (example for fzk)
" 16 70 '10.0.0.1:/home/fzk' 2>/tmp/dialog.ipt
        exportedfs=`cat /tmp/dialog.ipt`
        echo "Attempting to mount <$exportedfs> on /mnt/cdrom." | tee -a $i_log
        echo "Using read only and nolock mount options."
        /bin/mount -t nfs -o ro,nolock "$exportedfs" /mnt/cdrom 2>&1 | tee -a $i_log || {
            echo
            echo "NFS mount of $exportedfs failed." | tee -a $i_log
	    echo "In order to get this working:"
	    echo "1) setup networking on this local host (modprobe, ifconfig)"
	    echo "2) export a directory on the server see /etc/exports"
	    echo "3) setup nfs on the server (start nfsd)"
	    echo "4) copy all rpms of Fedora Core ${version} to directory $distri/RPMS"
	    stop_go
	    continue
        }
        echo
        echo "First step OK"
        echo "<$exportedfs> now mounted on /mnt/cdrom"
        mount | grep /mnt/cdrom
        if [ -d /mnt/cdrom/$distri/RPMS ]; then
	    echo
	    echo "Second step OK"
	    echo
            echo "Located </mnt/cdrom/$distri/RPMS> directory. Success!"
	    echo
	    umount /mnt/cdrom
	    sleep 3
	    break
        else
            echo
	    echo "Second step FAILED"
            echo "Failed to locate </mnt/cdrom/$distri/RPMS/>."
	    echo "You have to create the directory <$exportedfs/$distri/RPMS>"
	    echo "and copy all rpms of Fedora Core ${version} CD-1 into it."
	    stop_go
	    umount /mnt/cdrom
	fi
    done
    export exportedfs
    umount /mnt/cdrom
    ;;

'iso')
    # iso installs

    have_iso=0
    while [ "$have_iso" -ne "1" ]
    do
        while :
        do
	    dialog --no-collapse --inputbox \
"    You chose to install Fedora Core ISO from a local harddisk.
    I need to know what partition the ISO is located on.
    The possible partitions are: [ `echo ${avail_parts}` ]

    This input MUST NOT be a partition that will be part of
    the install.

    What partition is the ISO located on?
" 14 70 '' 2>/tmp/dialog.ipt
            iso_part=`cat /tmp/dialog.ipt`
            echo "Trying to mount /dev/${iso_part} on /mnt/loop" | tee -a $i_log
            umount /dev/${iso_part} 2>/dev/null
            mount /dev/${iso_part} /mnt/loop || {
		echo "Failed to mount /dev/${iso_part} on /mnt/loop." | tee -a $i_log
		echo "Try again.  If you are stuck here, RESET and restart from begin."
		stop_go
		umount /mnt/loop # > /dev/null 2>&1
		sleep 3
		continue
            }
            break
        done
        while :
        do
	    dialog --no-collapse --inputbox \
"    Please include the /path/to/the/file.iso if
    the file does not reside in the root directory.
    The usual name for Fedora Core ${version} disc1 is <$fc5_disc1>

    Enter path and name of the iso file or accept the default?
" 12 70 "$fc5_disc1" 2>/tmp/dialog.ipt
            iso_file=`cat /tmp/dialog.ipt`
	    echo "Trying to mount /dev/${iso_part}/${iso_file} on /mnt/cdrom." | tee -a $i_log
            mount -o loop,ro -t iso9660 /mnt/loop/${iso_file} /mnt/cdrom || {
		echo "Failed to mount /dev/${iso_part}/${iso_file} on /mnt/cdrom." | tee -a $i_log
		echo "Try again.  If you are stuck here, RESET and restart from begin."
		stop_go
		umount /mnt/cdrom > /dev/null 2>&1
		continue
            }
            export iso_file
            break
        done
    
        if [ -d /mnt/cdrom/$distri/RPMS ]; then
 	    echo
            echo "Located the $distri/RPMS/ directory! success." | tee -a $i_log
	    echo
            have_iso=1
            umount /mnt/cdrom > /dev/null 2>&1
        fi
    
        umount /mnt/cdrom > /dev/null 2>&1
    
        echo "Trying to mount Fedora ISOs disc2-4"
        stem=`echo "$iso_file" | sed -e 's/-disc1.iso//'`
        for i in 2 3 4
        do
            echo "Trying to mount /mnt/loop/${stem}-disc$i.iso on /mnt/cdrom" | tee -a $i_log
            mount -o loop,ro -t iso9660 /mnt/loop/${stem}-disc$i.iso /mnt/cdrom && {
		echo "Will also use ${stem}-disc$i.iso for this installation" | tee -a $i_log
		umount /mnt/cdrom > /dev/null 2>&1
            } || echo "${stem}-disc$i.iso couldn't be mounted" | tee -a $i_log
        done
    
        umount /mnt/cdrom > /dev/null 2>&1
        umount /mnt/loop > /dev/null 2>&1
    done
    export iso_part iso_file
    echo
    echo "You sucessfully selected iso-source $iso_part/$iso_file for installation" | tee -a $i_log
    echo
    stop_go
    ;;

'nfsiso')
    # nfsiso installs
    # Currently requires all ISOs to be in the same exported directory.
    # Files should be in the top-level-directory in the exported filesystem.

    while :
    do
	dialog --no-collapse --inputbox \
"    You choose to install ISOs via a nfs server.
    You need to provided the following:

    1) setup networking on this local host
    2) setup nfs on a server, know the name of the exported dir.
    3) copy $fc5_disc1 into this directory [exported directory]

    Please enter the name of the exported directory.
" 16 70 '10.0.0.1:/home/fzk' 2>/tmp/dialog.ipt
	exportedfs=`cat /tmp/dialog.ipt`

        echo
        echo "Attempting to mount <$exportedfs> on /mnt/cdrom." | tee -a $i_log
        echo "Using read only and nolock mount options."
        /bin/mount -t nfs -o ro,nolock "$exportedfs" /mnt/cdrom 2>&1 | tee -a $i_log || {
	    echo "NFS mount of <$exportedfs> on /mnt/cdrom failed." | tee -a $i_log
	    dialog --no-collapse --msgbox \
"    NFS mount of $exportedfs failed.
    In order to get this working:

    1) setup networking on this local host (modprobe, ifconfig)
    2) export a directory on the server see /etc/exports
    3) setup nfs on your server (start nfsd)
    4) copy all $distri ISOs into this directory [exported directory]
" 12 70
            stop_go
	    continue
        }
        echo
        echo "First step OK"
        echo "<$exportedfs> now mounted on /mnt/cdrom"
        mount | grep /mnt/cdrom
	sleep 3

        while :
        do
	    dialog --no-collapse --inputbox \
"    Now include the /path/to/the/file.iso if the file does
    not reside in the root directory <$exportedfs>
    The usual name for Fedora Core ${version} disc1 is
    [ $fc5_disc1 ]
    
    Enter path and name of the iso file or accept the default.
" 16 70 "$fc5_disc1" 2>/tmp/dialog.ipt
            iptfilename=`cat /tmp/dialog.ipt`
            [ -z "$iptfilename" ] && iso_file="$fc5_disc1" || iso_file="$iptfilename"

	    if [ -r /mnt/cdrom/$iso_file ]; then
		echo
		echo "Located the <$exportedfs/$iso_file>. Success!" | tee -a $i_log
		echo
		have_iso=1
# 		echo "Trying to find Fedora ISOs disc2-4"
# 		stem=`echo "$iso_file" | sed -e 's/-disc1.iso//'`
# 		for i in 2 3 4
# 		do
# 		    [ -r /mnt/cdrom/$stem-disc$i.iso ] && {
# 			echo "Will also use $exportedfs/${stem}-disc$i.iso for this installation" | tee -a $i_log
# 		    } || echo "$exportedfs/${stem}-disc$i.iso couldn't be located"
# 		done
		break
	    else
		echo "$distri ISO <$exportedfs/$iso_file> not found, try again" | tee -a $i_log
		stop_go
	    fi
	done
	break
    done
    export exportedfs iso_file
    umount /mnt/cdrom
    stop_go
    ;;

'rpms')
    # Local rpm files on the hard drive.
    # RPMs should be in $distri/RPMS in the root of the partition.

    have_rpms=0
    while [ "$have_rpms" -ne "1" ]
    do
        dialog --no-collapse --inputbox \
"    You choose to install rpms located on a local harddisk.
    I need to know what partition the rpms are located on.
    The possible partitions are: [ `echo ${avail_parts}` ]

    This input MUST NOT be a partition that will be part of
    the install.

    What partition is the $distri/RPMS directory located on? :
" 16 70 '' 2>/tmp/dialog.ipt
        iso_part=`cat /tmp/dialog.ipt`
        echo "Trying to mount /dev/${iso_part} on /mnt/cdrom" | tee -a $i_log
	mount /dev/${iso_part} /mnt/cdrom || {
	    echo
	    echo "Failed to mount /dev/${iso_part} on /mnt/cdrom." | tee -a $i_log
	    echo
	    stop_go
	    have_rpms=0
	    continue
	}

        while :
        do
	    dialog --no-collapse --inputbox \
"    Please include the /path/to/the/RPMS.
    The usual directory name for Fedora Core ${version} rpms is
    $distri/RPMS.

    Enter path and name to the rpms or accept the default?
" 12 70 "$distri/RPMS" 2>/tmp/dialog.ipt
            rpmpath=`cat /tmp/dialog.ipt`
	    echo "Trying to locate the directory $rpmpath on /dev/${iso_part}" | tee -a $i_log
	    if [ -d /mnt/cdrom/$distri/RPMS ]; then
		echo
		echo "Located the $rpmpath directory on /dev/${iso_part}. Success!" | tee -a $i_log
		echo
		have_rpms=1
		sleep 3
	    else
		echo
		echo "Failed to locate $rpmpath directory on /dev/${iso_part}." | tee -a $i_log
		echo Retry
		echo
		stop_go
		have_rpms=0
		continue
	    fi

            export rpmpath
            break
        done

	umount /mnt/cdrom
    done
    export iso_part
    echo
    ;;

* )
    # cdrom installs (default)
    # Find the cdrom, and hope that the entry in /proc is correct.

    # cd_device=`grep "drive name" /proc/sys/dev/cdrom/info | cut -d : -f 2 | cut -f 3`
    cd_device=`grep cdrom /proc/ide/hd?/media | head -n1 | cut -d/ -f4`
    echo CD probe=$cd_device >> $i_log

    have_device=0
    while [ "$have_device" -ne "1" ]
    do
        case "$cd_device" in
        hda) CDROM_DEV=/dev/hda
            have_device=1
            export CDROM_DEV
            ;;
        hdb) CDROM_DEV=/dev/hdb
            have_device=1
            export CDROM_DEV
            ;;
        hdc) CDROM_DEV=/dev/hdc
            have_device=1
            export CDROM_DEV
            ;;
        hdd) CDROM_DEV=/dev/hdd
            have_device=1
            export CDROM_DEV
            ;;
        cdrom) CDROM_DEV=/dev/cdrom
            have_device=1
            export CDROM_DEV
            ;;
        esac

    if [ -z "$CDROM_DEV" ]; then
	dialog --no-collapse --inputbox \
"    I wasn't able to locate your cdrom drive.
    The 'cdrom' entry below should be used only if
    your drive is nonstandard, and you have created
    a link from /dev/cdrom to the actual device.

    Please enter the device that represents
    your cdrom device. [ hda hdb hdc hdd cdrom ]:
" 12 70 '' 2>/tmp/dialog.ipt
	CDROM_DEV=/dev/`cat /tmp/dialog.ipt`
    fi

	dialog --no-collapse --msgbox \
"    Trying to use <$CDROM_DEV> as your cd drive.
    You will have the opportunity to change this
    later in the install, if need be.
" 12 70
        have_device=1
    done

    echo CDROM_DEV=$CDROM_DEV >> $i_log
    ;;

esac
