#!/bin/sh

# create SLINKY module-floppy
# All Modules are located under .../lib/modules/${kernel-version}
# Copy the modules you need to /tmp/${kernel-version} and test the size.
# du -sk /tmp/${kernel-version} should report a size less than 1440KB
#
# This script copies these files to a Floppy.
# This floppy can be mounted later while installing
# with slinky at /lib/modules/

# set -x

. version.h

image=${version}-modules1.img

trap "echo unmounting modulesdisk1 from loop; umount `pwd`/${image}" 0

echo
echo "Creating modules disk ${image}."

rm ${image}
dd if=/dev/zero of=${image} bs=1024 count=1440 || {
    echo "Error while creating ${image}, exiting."
    exit
}

mkfs.ext2 -F -m 0 -N 200 -b 1024 ${image} || {
    echo "Error while making ext2 filesystem on ${image}, exiting."
    exit
}

echo "Mounting ${image} on the loop device."
mount -o loop ${image} loop/ || {
    echo "Error mounting filesystem, exiting."
    exit
}

rm -rf loop/lost+found
echo "Copying modules."
cp -a /tmp/${ik_version} loop || {
    echo "Error copying filesystem, exiting."
    exit
}

echo "Unmounting loop filesystem."
umount loop || {
    echo "Error unmounting loop filesystem, exiting."
    exit
}

echo "Moving ${image} to slinky directory."
mkdir -p slinky-images/${version}
mv ${image} slinky-images/${version} || {
    echo "Error moving ${image}."
    exit
}

echo creating a floppy with: dd if=slinky-images/${version}/${image} of=/dev/fd0 bs=512
dd if=slinky-images/${version}/${image} of=/dev/fd0 bs=512
echo
echo "Done."
exit

